@@ -10,7 +10,6 @@ import importlib
 
 
 class Index(Command):
-
     def find_model_classes(self):
         classes = []
         model_dir = os.path.join(self.app.app_dir, "models")
@@ -27,7 +26,7 @@ class Index(Command):
                             StorableSubmodel,
                             ShardedSubmodel,
                             StorableModel,
-                            ShardedModel
+                            ShardedModel,
                         ]:
                             classes.append(obj)
         return classes
